==> antlr-java-parser-1.0.2-sources.jar: com/github/antlrjavaparser/adapter/AnnotationTypeDeclarationContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.body.AnnotationDeclaration;

public class AnnotationTypeDeclarationContextAdapter implements Adapter<AnnotationDeclaration, Java7Parser.AnnotationTypeDeclarationContext> {
    public AnnotationDeclaration adapt(Java7Parser.AnnotationTypeDeclarationContext context) {

        AnnotationDeclaration annotationDeclaration = new AnnotationDeclaration();

        AdapterUtil.setModifiers(context.modifiers(), annotationDeclaration);
        annotationDeclaration.setName(context.Identifier().getText());
        annotationDeclaration.setMembers(Adapters.getAnnotationTypeBodyContextAdapter().adapt(context.annotationTypeBody()));

        return annotationDeclaration;
    }
}

==> antlr-java-parser-1.0.6-sources.jar: com/github/antlrjavaparser/adapter/AnnotationTypeDeclarationContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.body.AnnotationDeclaration;

public class AnnotationTypeDeclarationContextAdapter implements Adapter<AnnotationDeclaration, Java7Parser.AnnotationTypeDeclarationContext> {
    public AnnotationDeclaration adapt(Java7Parser.AnnotationTypeDeclarationContext context, AdapterParameters adapterParameters) {

        AnnotationDeclaration annotationDeclaration = new AnnotationDeclaration();
        AdapterUtil.setComments(annotationDeclaration, context, adapterParameters);

        AdapterUtil.setModifiers(context.modifiers(), annotationDeclaration, adapterParameters);
        annotationDeclaration.setName(context.Identifier().getText());
        annotationDeclaration.setMembers(Adapters.getAnnotationTypeBodyContextAdapter().adapt(context.annotationTypeBody(), adapterParameters));

        return annotationDeclaration;
    }
}
